@@ -6,14 +6,13 @@
 
 use std::convert::TryFrom;
 
+#[cfg(target_os = "linux")]
+use libc::{SCHED_BATCH, SCHED_IDLE};
+use libc::{SCHED_FIFO, SCHED_OTHER, SCHED_RR};
+
 use crate::{Error, ThreadPriority, ThreadPriorityValue};
 use std::mem::MaybeUninit;
 
-#[cfg(not(target_os = "macos"))]
-const SCHED_FIFO: i32 = 1;
-#[cfg(target_os = "macos")]
-const SCHED_FIFO: i32 = 4;
-
 // Processes scheduled under one of the real-time policies
 // (SCHED_FIFO, SCHED_RR) have a sched_priority value in the range 1
 // (low) to 99 (high).
@@ -35,11 +34,11 @@ pub struct ScheduleParams {
 fn errno() -> libc::c_int {
     unsafe {
         cfg_if::cfg_if! {
-            if #[cfg(any(target_os = "openbsd", target_os = "freebsd", target_os = "netbsd"))] {
+            if #[cfg(any(target_os = "openbsd", target_os = "netbsd"))] {
                 *libc::__errno()
             } else if #[cfg(target_os = "linux")] {
                 *libc::__errno_location()
-            } else if #[cfg(target_os = "macos")] {
+            } else if #[cfg(any(target_os = "macos", target_os = "freebsd"))] {
                 *libc::__error()
             } else {
                 compile_error!("Your OS is probably not supported.")
@@ -108,7 +107,7 @@ impl RealtimeThreadSchedulePolicy {
     fn to_posix(self) -> libc::c_int {
         match self {
             RealtimeThreadSchedulePolicy::Fifo => SCHED_FIFO,
-            RealtimeThreadSchedulePolicy::RoundRobin => 2,
+            RealtimeThreadSchedulePolicy::RoundRobin => SCHED_RR,
             #[cfg(all(target_os = "linux", not(target_arch = "wasm32")))]
             RealtimeThreadSchedulePolicy::Deadline => 6,
         }
@@ -119,31 +118,22 @@ impl RealtimeThreadSchedulePolicy {
 #[derive(Debug, Copy, Clone, Eq, PartialEq, Ord, PartialOrd, Hash)]
 pub enum NormalThreadSchedulePolicy {
     /// For running very low priority background jobs
-    #[cfg(not(target_os = "macos"))]
+    #[cfg(target_os = "linux")]
     Idle,
     /// For "batch" style execution of processes
-    #[cfg(not(target_os = "macos"))]
+    #[cfg(target_os = "linux")]
     Batch,
     /// The standard round-robin time-sharing policy
     Other,
-    /// The standard round-robin time-sharing policy
-    #[cfg(not(target_os = "macos"))]
-    Normal,
 }
 impl NormalThreadSchedulePolicy {
-    #[cfg(not(target_os = "macos"))]
     fn to_posix(self) -> libc::c_int {
         match self {
-            NormalThreadSchedulePolicy::Idle => 5,
-            NormalThreadSchedulePolicy::Batch => 3,
-            NormalThreadSchedulePolicy::Other | NormalThreadSchedulePolicy::Normal => 0,
-        }
-    }
-
-    #[cfg(target_os = "macos")]
-    fn to_posix(self) -> libc::c_int {
-        match self {
-            NormalThreadSchedulePolicy::Other => 1,
+            #[cfg(target_os = "linux")]
+            NormalThreadSchedulePolicy::Idle => SCHED_IDLE,
+            #[cfg(target_os = "linux")]
+            NormalThreadSchedulePolicy::Batch => SCHED_BATCH,
+            NormalThreadSchedulePolicy::Other => SCHED_OTHER,
         }
     }
 }
@@ -164,22 +154,23 @@ impl ThreadSchedulePolicy {
         }
     }
 
-    #[cfg(not(target_os = "macos"))]
     fn from_posix(policy: libc::c_int) -> Result<ThreadSchedulePolicy, Error> {
         match policy {
-            0 => Ok(ThreadSchedulePolicy::Normal(
-                NormalThreadSchedulePolicy::Normal,
+            SCHED_OTHER => Ok(ThreadSchedulePolicy::Normal(
+                NormalThreadSchedulePolicy::Other,
             )),
-            3 => Ok(ThreadSchedulePolicy::Normal(
+            #[cfg(target_os = "linux")]
+            SCHED_BATCH => Ok(ThreadSchedulePolicy::Normal(
                 NormalThreadSchedulePolicy::Batch,
             )),
-            5 => Ok(ThreadSchedulePolicy::Normal(
+            #[cfg(target_os = "linux")]
+            SCHED_IDLE => Ok(ThreadSchedulePolicy::Normal(
                 NormalThreadSchedulePolicy::Idle,
             )),
             SCHED_FIFO => Ok(ThreadSchedulePolicy::Realtime(
                 RealtimeThreadSchedulePolicy::Fifo,
             )),
-            2 => Ok(ThreadSchedulePolicy::Realtime(
+            SCHED_RR => Ok(ThreadSchedulePolicy::Realtime(
                 RealtimeThreadSchedulePolicy::RoundRobin,
             )),
             #[cfg(all(target_os = "linux", not(target_arch = "wasm32")))]
@@ -189,24 +180,6 @@ impl ThreadSchedulePolicy {
             _ => Err(Error::Ffi("Can't parse schedule policy from posix")),
         }
     }
-
-    #[cfg(target_os = "macos")]
-    fn from_posix(policy: libc::c_int) -> Result<ThreadSchedulePolicy, Error> {
-        match policy {
-            1 => Ok(ThreadSchedulePolicy::Normal(
-                NormalThreadSchedulePolicy::Other,
-            )),
-            SCHED_FIFO => Ok(ThreadSchedulePolicy::Realtime(
-                RealtimeThreadSchedulePolicy::Fifo,
-            )),
-            2 => Ok(ThreadSchedulePolicy::Realtime(
-                RealtimeThreadSchedulePolicy::RoundRobin,
-            )),
-            _ => Err(Error::Ffi(
-                "Can't parse schedule policy from berkley values",
-            )),
-        }
-    }
 }
 
 impl ThreadPriority {
