@@ -4,12 +4,11 @@ use rstest::rstest;
 use std::convert::TryInto;
 use thread_priority::*;
 
-#[cfg(not(target_os = "macos"))]
+#[cfg(target_os = "linux")]
 #[rstest]
 fn get_and_set_priority_with_normal_policies(
     #[values(
         ThreadSchedulePolicy::Normal(NormalThreadSchedulePolicy::Other),
-        ThreadSchedulePolicy::Normal(NormalThreadSchedulePolicy::Normal),
         ThreadSchedulePolicy::Normal(NormalThreadSchedulePolicy::Idle),
         ThreadSchedulePolicy::Normal(NormalThreadSchedulePolicy::Batch)
     )]
@@ -26,7 +25,12 @@ fn get_and_set_priority_with_normal_policies(
     assert!(set_thread_priority_and_policy(thread_native_id(), correct_priority, policy,).is_ok());
 }
 
-#[cfg(target_os = "macos")]
+#[cfg(any(
+    target_os = "macos",
+    target_os = "openbsd",
+    target_os = "freebsd",
+    target_os = "netbsd"
+))]
 #[rstest]
 fn get_and_set_priority_with_normal_policies(
     #[values(ThreadSchedulePolicy::Normal(NormalThreadSchedulePolicy::Other))]
@@ -38,10 +42,10 @@ fn get_and_set_priority_with_normal_policies(
     assert!(set_thread_priority_and_policy(thread_native_id(), priority, policy,).is_ok());
 }
 
-#[cfg(not(target_os = "macos"))]
 #[rstest]
-#[case(ThreadSchedulePolicy::Normal(NormalThreadSchedulePolicy::Normal), 0..=0)]
+#[cfg(target_os = "linux")]
 #[case(ThreadSchedulePolicy::Normal(NormalThreadSchedulePolicy::Idle), 0..=0)]
+#[cfg(target_os = "linux")]
 #[case(ThreadSchedulePolicy::Normal(NormalThreadSchedulePolicy::Batch), 0..=0)]
 #[case(ThreadSchedulePolicy::Normal(NormalThreadSchedulePolicy::Other), 0..=0)]
 #[case(ThreadSchedulePolicy::Realtime(RealtimeThreadSchedulePolicy::Fifo), 0..=99)]
@@ -56,33 +60,13 @@ fn check_min_and_max_priority_values(
     assert!(posix_range.contains(&min_value));
 }
 
-#[cfg(target_os = "macos")]
 #[rstest]
-fn check_min_and_max_priority_values(
-    #[values(
-        ThreadSchedulePolicy::Normal(NormalThreadSchedulePolicy::Other),
-        ThreadSchedulePolicy::Realtime(RealtimeThreadSchedulePolicy::Fifo),
-        ThreadSchedulePolicy::Realtime(RealtimeThreadSchedulePolicy::RoundRobin)
-    )]
-    policy: ThreadSchedulePolicy,
-) {
-    let posix_range = 0..=99;
-
-    let max_value = ThreadPriority::max_value_for_policy(policy).unwrap();
-    let min_value = ThreadPriority::min_value_for_policy(policy).unwrap();
-    assert!(posix_range.contains(&max_value));
-    assert!(posix_range.contains(&min_value));
-}
-
-#[cfg(not(target_os = "macos"))]
-#[rstest]
-#[case(ThreadSchedulePolicy::Normal(NormalThreadSchedulePolicy::Normal))]
+#[cfg(target_os = "linux")]
 #[case(ThreadSchedulePolicy::Normal(NormalThreadSchedulePolicy::Idle))]
+#[cfg(target_os = "linux")]
 #[case(ThreadSchedulePolicy::Normal(NormalThreadSchedulePolicy::Batch))]
 #[case(ThreadSchedulePolicy::Normal(NormalThreadSchedulePolicy::Other))]
 fn set_priority_with_normal_policy_but_with_invalid_value(#[case] policy: ThreadSchedulePolicy) {
-    use std::convert::TryInto;
-
     let thread_id = thread_native_id();
 
     assert_eq!(
@@ -97,12 +81,15 @@ fn set_priority_with_normal_policy_but_with_invalid_value(#[case] policy: Thread
     );
 }
 
-#[cfg(target_os = "macos")]
+#[cfg(any(
+    target_os = "macos",
+    target_os = "openbsd",
+    target_os = "freebsd",
+    target_os = "netbsd"
+))]
 #[test]
 // In macOS the SCHED_OTHER policy allows having a non-zero priority value.
 fn get_and_set_priority_with_normal_policy() {
-    use std::convert::TryInto;
-
     let thread_id = thread_native_id();
     let normal_policy = ThreadSchedulePolicy::Normal(NormalThreadSchedulePolicy::Other);
 
@@ -134,8 +121,6 @@ fn get_and_set_priority_with_normal_policy() {
 fn get_and_set_priority_with_realtime_policy_requires_capabilities(
     #[case] realtime_policy: ThreadSchedulePolicy,
 ) {
-    use std::convert::TryInto;
-
     let thread_id = thread_native_id();
     let max_value = ThreadPriority::max_value_for_policy(realtime_policy).unwrap();
     let min_value = ThreadPriority::min_value_for_policy(realtime_policy).unwrap();
